ErrorContext

Trait ErrorContext 

pub trait ErrorContext<T> {
    // Required method
    fn with_context<C>(self, context: C) -> Result<T>
       where C: FnOnce() -> String;
}
Extension trait for adding context to I/O errors.

This trait provides a convenient way to convert std::io::Result into Result with descriptive context about what operation failed.

Required Methods

fn with_context<C>(self, context: C) -> Result<T>
where C: FnOnce() -> String,

Adds context to an error, describing what action was being performed.

Arguments
  • context - A closure that returns a description of the failed action

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementations on Foreign Types

Source

impl<T> ErrorContext<T> for Result<T>

Source

fn with_context<C>(self, context: C) -> Result<T>
where C: FnOnce() -> String,

Implementors